support and contact channels — tox 2.9.0rc2.dev53 documentation

# support and contact channels

Getting in contact:

- file a report on the issue tracker
- join the tox-dev mailing list for tox related questions, discussions and release announcements.
- fork the github repository and submit merge/pull requests (see the developers help page – Developers FAQ)
- hang out on the irc.freenode.net #pylib channel
- join the Testing In Python (TIP) mailing list for tool transcneding discussions about these topics

## paid professional support

contact holger (holger-twitter) at merlinux.eu, an association of experienced well-known Python developers.